import { Db } from 'mongodb';
/**
 * Provides functionality for managing documents, collections in database.
 */
export declare class Database {
    db: Db;
    /**
     * Constructs a new `Database` object.
     *
     * @param db MongoDB database object
     */
    constructor(db: Db);
    /**
     * Inserts documents into a given collection.
     *
     * @param documentsToInsert Array of documents, which are being imported
     * @param collectionName Collection name
     */
    insertDocumentsIntoCollection(documentsToInsert: any[], collectionName: string): Promise<import("mongodb").InsertWriteOpResult>;
    /**
     * Drops database.
     */
    drop(): Promise<any>;
    /**
     * Checks if a given collection exist.
     *
     * @param collectionName Collection name
     */
    ifCollectionExist(collectionName: string): Promise<boolean>;
    /**
     * Drops a given collection if exists.
     *
     * @param collectionName Collection name
     */
    dropCollectionIfExists(collectionName: string): Promise<any>;
}
